==> jc-1.4.0.tar.gz: gnu/java/nio/ChannelInputStream.h <==
// public final class gnu.java.nio.ChannelInputStream

// class file dependencies
// @dep_class c0b174cad2da2e49 gnu_java_nio_ChannelInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_InputStream

#include "java/io/InputStream.h"

#ifndef _JC_gnu_java_nio_ChannelInputStream_H_
#define _JC_gnu_java_nio_ChannelInputStream_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_ReadableByteChannel$object;

// Typedefs
typedef struct _jc_gnu_java_nio_ChannelInputStream$sub_refs	_jc_gnu_java_nio_ChannelInputStream$sub_refs;
typedef struct _jc_gnu_java_nio_ChannelInputStream$sub_nonrefs	_jc_gnu_java_nio_ChannelInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_nio_ChannelInputStream$refs	_jc_gnu_java_nio_ChannelInputStream$refs;
typedef struct _jc_gnu_java_nio_ChannelInputStream$nonrefs	_jc_gnu_java_nio_ChannelInputStream$nonrefs;
typedef struct _jc_gnu_java_nio_ChannelInputStream$object	_jc_gnu_java_nio_ChannelInputStream$object;

typedef const struct _jc_gnu_java_nio_ChannelInputStream$vmethods	_jc_gnu_java_nio_ChannelInputStream$vmethods;
typedef const struct _jc_gnu_java_nio_ChannelInputStream$vtable	_jc_gnu_java_nio_ChannelInputStream$vtable;
typedef const struct _jc_gnu_java_nio_ChannelInputStream$vtype	_jc_gnu_java_nio_ChannelInputStream$vtype;

// Constructors
extern void _jc_gnu_java_nio_ChannelInputStream$method$_init$ac0df0925a7cce9f(_jc_env *, struct _jc_gnu_java_nio_ChannelInputStream$object *, struct _jc_object *);

// Virtual methods
extern jint _jc_gnu_java_nio_ChannelInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_gnu_java_nio_ChannelInputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_ChannelInputStream$method_info$read$1a981297cb524963;

// Virtual methods structure
struct _jc_gnu_java_nio_ChannelInputStream$vmethods {
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_gnu_java_nio_ChannelInputStream$object *);
};

// Vtable
struct _jc_gnu_java_nio_ChannelInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_gnu_java_nio_ChannelInputStream$vmethods	gnu_java_nio_ChannelInputStream;
};

// Vtype
struct _jc_gnu_java_nio_ChannelInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_ChannelInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_ChannelInputStream$sub_refs {
	struct _jc_object	*ch;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_ChannelInputStream$refs {
    _jc_gnu_java_nio_ChannelInputStream$sub_refs	gnu_java_nio_ChannelInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_ChannelInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_ChannelInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_gnu_java_nio_ChannelInputStream$sub_nonrefs	gnu_java_nio_ChannelInputStream;
};

// Object instance structure
struct _jc_gnu_java_nio_ChannelInputStream$object {
	_jc_gnu_java_nio_ChannelInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_ChannelInputStream$vtype	*vtype;
	_jc_gnu_java_nio_ChannelInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_ChannelInputStream$vtype _jc_gnu_java_nio_ChannelInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_ChannelInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_ChannelInputStream$class_object;

#endif	/* _JC_gnu_java_nio_ChannelInputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/java/nio/ChannelInputStream.h <==
// public final class gnu.java.nio.ChannelInputStream

// class file dependencies
// @dep_class c0b174cad2da2e49 gnu_java_nio_ChannelInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_InputStream

#include "java/io/InputStream.h"

#ifndef _JC_gnu_java_nio_ChannelInputStream_H_
#define _JC_gnu_java_nio_ChannelInputStream_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_ReadableByteChannel$object;

// Typedefs
typedef struct _jc_gnu_java_nio_ChannelInputStream$sub_refs	_jc_gnu_java_nio_ChannelInputStream$sub_refs;
typedef struct _jc_gnu_java_nio_ChannelInputStream$sub_nonrefs	_jc_gnu_java_nio_ChannelInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_nio_ChannelInputStream$refs	_jc_gnu_java_nio_ChannelInputStream$refs;
typedef struct _jc_gnu_java_nio_ChannelInputStream$nonrefs	_jc_gnu_java_nio_ChannelInputStream$nonrefs;
typedef struct _jc_gnu_java_nio_ChannelInputStream$object	_jc_gnu_java_nio_ChannelInputStream$object;

typedef const struct _jc_gnu_java_nio_ChannelInputStream$vmethods	_jc_gnu_java_nio_ChannelInputStream$vmethods;
typedef const struct _jc_gnu_java_nio_ChannelInputStream$vtable	_jc_gnu_java_nio_ChannelInputStream$vtable;
typedef const struct _jc_gnu_java_nio_ChannelInputStream$vtype	_jc_gnu_java_nio_ChannelInputStream$vtype;

// Constructors
extern void _jc_gnu_java_nio_ChannelInputStream$method$_init$ac0df0925a7cce9f(_jc_env *, struct _jc_gnu_java_nio_ChannelInputStream$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_nio_ChannelInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_gnu_java_nio_ChannelInputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_ChannelInputStream$method_info$read$1a981297cb524963;

// Virtual methods structure
struct _jc_gnu_java_nio_ChannelInputStream$vmethods {
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_gnu_java_nio_ChannelInputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_ChannelInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_gnu_java_nio_ChannelInputStream$vmethods	gnu_java_nio_ChannelInputStream;
};

// Vtype
struct _jc_gnu_java_nio_ChannelInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_ChannelInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_ChannelInputStream$sub_refs {
	struct _jc_object	*ch;
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_ChannelInputStream$refs {
    _jc_gnu_java_nio_ChannelInputStream$sub_refs	gnu_java_nio_ChannelInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_ChannelInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_ChannelInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_gnu_java_nio_ChannelInputStream$sub_nonrefs	gnu_java_nio_ChannelInputStream;
};

// Object instance structure
struct _jc_gnu_java_nio_ChannelInputStream$object {
	_jc_gnu_java_nio_ChannelInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_ChannelInputStream$vtype	*vtype;
	_jc_gnu_java_nio_ChannelInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_ChannelInputStream$vtype _jc_gnu_java_nio_ChannelInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_ChannelInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_ChannelInputStream$class_object;

#endif	/* _JC_gnu_java_nio_ChannelInputStream_H_ */
